==> maven-jar-plugin-3.4.2-source-release.zip: maven-jar-plugin-3.4.2/src/test/java/org/apache/maven/plugins/jar/JarMojoTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.plugins.jar;

import org.apache.maven.plugin.testing.junit5.InjectMojo;
import org.apache.maven.plugin.testing.junit5.MojoTest;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertNotNull;

/**
 * Test for {@link JarMojo}
 *
 * @version $Id$
 */
@MojoTest
class JarMojoTest {

    /**
     * Tests the discovery and configuration of the mojo.
     */
    @Test
    @InjectMojo(goal = "jar", pom = "classpath:/unit/jar-basic-test/pom.xml")
    void testJarTestEnvironment(JarMojo mojo) {
        assertNotNull(mojo);
        assertEquals("foo", mojo.getProject().getGroupId());
    }
}

==> maven-jar-plugin-3.5.0-source-release.zip: maven-jar-plugin-3.5.0/src/test/java/org/apache/maven/plugins/jar/JarMojoTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.plugins.jar;

import javax.inject.Inject;

import org.apache.maven.api.plugin.testing.InjectMojo;
import org.apache.maven.api.plugin.testing.MojoTest;
import org.apache.maven.project.MavenProject;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertNotNull;
import static org.junit.jupiter.api.Assertions.assertSame;

/**
 * Test for {@link JarMojo}
 *
 * @version $Id$
 */
@MojoTest
class JarMojoTest {

    @Inject
    private MavenProject project;

    /**
     * Tests the discovery and configuration of the mojo.
     */
    @Test
    @InjectMojo(goal = "jar")
    void testJarTestEnvironment(JarMojo mojo) {
        assertNotNull(mojo);
        assertSame(project, mojo.getProject());
    }
}
